import React, { useState } from 'react';
import { BrainCircuit, ArrowRight, Trophy } from 'lucide-react';

const quizQuestions = [
  {
    question: 'What is the minimum recommended length for a strong password?',
    options: ['6 characters', '8 characters', '12 characters', '16 characters'],
    correct: 2,
  },
  {
    question: 'Which of the following is the most secure password?',
    options: [
      'Password123!',
      'MyBirthday1990',
      'k9#mP2$vL5nX',
      'ilovemydog',
    ],
    correct: 2,
  },
  {
    question: 'What is two-factor authentication (2FA)?',
    options: [
      'Using two different passwords',
      'Having two email addresses',
      'Using a password and an additional verification method',
      'Changing your password twice',
    ],
    correct: 2,
  },
  {
    question: 'Which practice is most dangerous for password security?',
    options: [
      'Using a password manager',
      'Using the same password for multiple accounts',
      'Using special characters',
      'Changing passwords regularly',
    ],
    correct: 1,
  },
  {
    question: 'What is a phishing attack?',
    options: [
      'A virus that deletes passwords',
      'An attempt to trick users into revealing sensitive information',
      'A type of secure password',
      'A password recovery method',
    ],
    correct: 1,
  },
];

export default function SecurityQuiz() {
  const [currentQuestion, setCurrentQuestion] = useState(0);
  const [selectedAnswer, setSelectedAnswer] = useState<number | null>(null);
  const [score, setScore] = useState(0);
  const [quizComplete, setQuizComplete] = useState(false);

  const handleAnswer = (answerIndex: number) => {
    setSelectedAnswer(answerIndex);
  };

  const handleNext = () => {
    if (selectedAnswer === quizQuestions[currentQuestion].correct) {
      setScore(score + 1);
    }

    if (currentQuestion < quizQuestions.length - 1) {
      setCurrentQuestion(currentQuestion + 1);
      setSelectedAnswer(null);
    } else {
      setQuizComplete(true);
    }
  };

  const resetQuiz = () => {
    setCurrentQuestion(0);
    setSelectedAnswer(null);
    setScore(0);
    setQuizComplete(false);
  };

  const getScoreMessage = () => {
    const percentage = (score / quizQuestions.length) * 100;
    if (percentage === 100) return 'Perfect! You\'re a security expert!';
    if (percentage >= 80) return 'Great job! You\'re well-informed about security!';
    if (percentage >= 60) return 'Good effort! Keep learning about security!';
    return 'Time to brush up on your security knowledge!';
  };

  return (
    <div className="max-w-2xl mx-auto">
      <div className="bg-slate-800/50 rounded-lg p-6 shadow-xl">
        <h2 className="text-xl font-bold mb-4 flex items-center gap-2">
          <BrainCircuit className="text-purple-400" />
          Cybersecurity Knowledge Quiz
        </h2>

        {!quizComplete ? (
          <div className="space-y-6">
            <div className="mb-4">
              <div className="flex justify-between text-sm text-slate-400 mb-2">
                <span>Question {currentQuestion + 1} of {quizQuestions.length}</span>
                <span>Score: {score}</span>
              </div>
              <div className="w-full bg-slate-700 rounded-full h-2">
                <div
                  className="bg-purple-400 h-2 rounded-full transition-all"
                  style={{ width: `${((currentQuestion + 1) / quizQuestions.length) * 100}%` }}
                />
              </div>
            </div>

            <div className="space-y-4">
              <h3 className="text-lg font-medium">
                {quizQuestions[currentQuestion].question}
              </h3>

              <div className="space-y-2">
                {quizQuestions[currentQuestion].options.map((option, index) => (
                  <button
                    key={index}
                    onClick={() => handleAnswer(index)}
                    className={`w-full p-3 rounded-lg text-left transition ${
                      selectedAnswer === index
                        ? 'bg-purple-500 text-white'
                        : 'bg-slate-700 hover:bg-slate-600'
                    }`}
                  >
                    {option}
                  </button>
                ))}
              </div>
            </div>

            <button
              onClick={handleNext}
              disabled={selectedAnswer === null}
              className={`w-full py-2 px-4 rounded-lg transition flex items-center justify-center gap-2 ${
                selectedAnswer === null
                  ? 'bg-slate-700 text-slate-400 cursor-not-allowed'
                  : 'bg-purple-500 hover:bg-purple-600 text-white'
              }`}
            >
              {currentQuestion === quizQuestions.length - 1 ? 'Finish Quiz' : 'Next Question'}
              <ArrowRight className="w-4 h-4" />
            </button>
          </div>
        ) : (
          <div className="text-center space-y-6">
            <div className="flex justify-center">
              <Trophy className="w-16 h-16 text-yellow-400" />
            </div>
            <div>
              <h3 className="text-2xl font-bold mb-2">Quiz Complete!</h3>
              <p className="text-lg">
                Your score: {score} out of {quizQuestions.length}
              </p>
              <p className="text-slate-400 mt-2">{getScoreMessage()}</p>
            </div>
            <button
              onClick={resetQuiz}
              className="py-2 px-4 bg-purple-500 hover:bg-purple-600 text-white rounded-lg transition"
            >
              Try Again
            </button>
          </div>
        )}
      </div>
    </div>
  );
}